@@ -22,15 +22,17 @@ def pytest_runtest_makereport(item, call):
     extra = getattr(report, "extra", [])
     screenshot = item.config.option.screenshot
 
+#report.when value --setup, call, teardown
     if report.when == 'call':
         if not (screenshot == 'failonly' and report.outcome == 'passed'):
             # item.module.test_obj.gif_file_name
             f_name = None
             if item.config.option.bdd_flag == 'Y':
-                f_name = item.module.test_obj.gif_file_name
+                f_name = item.module.test_obj.write_test_summary()
             elif 'test_obj' in item.funcargs and item.funcargs['test_obj'].gif_file_name:
                 f_name = item.funcargs['test_obj'].gif_file_name
-
+            elif 'test_mobile_obj' in item.funcargs and item.funcargs['test_mobile_obj'].gif_file_name:
+                f_name = item.funcargs['test_mobile_obj'].gif_file_name
             if f_name:
                 extra.append(extras.image(f_name, mime_type='image/gif', extension='gif'))
         report.extra = extra
