@@ -2,7 +2,7 @@
 Qxf2 Services: A plug-n-play class for logging.
 This class wraps around Python's loguru module.
 """
-import os, inspect
+import os, inspect, sys
 import pytest, logging
 from loguru import logger
 from reportportal_client import RPLogger, RPLogHandler
@@ -35,6 +35,10 @@ class Base_Logging():
         logger.add(log_file_name, level=level, format=format,
                    rotation="30 days", filter=None, colorize=None, serialize=False, backtrace=True, enqueue=False,
                    catch=True)
+        logger.add(sys.stdout, level=level, format=format,
+                   # rotation="30 days",
+                   filter=None, colorize=None, serialize=False, backtrace=True, enqueue=False,
+                   catch=True)
 
     def get_calling_module(self):
         "Get the name of the calling module"
